import { type Extension } from '@codemirror/state';
import { EditorView } from '@codemirror/view';
import { type DockPosition } from '../sidebar';
import { type File } from './state';
export interface ExplorerOptions {
    /**
     * Which side to dock the explorer on
     * @default 'left'
     */
    dock?: DockPosition;
    /**
     * Width of the explorer panel
     * @default '250px'
     */
    width?: string;
    /**
     * Keyboard shortcut to toggle the explorer
     * Can be a string for same shortcut on all platforms
     * or an object for platform-specific shortcuts
     * @example 'Cmd-e' or { mac: 'Cmd-e', win: 'Ctrl-e' }
     */
    keymap?: string | {
        mac: string;
        win: string;
    };
    /**
     * Whether to show the explorer as an overlay
     * @default false
     */
    overlay?: boolean;
    /**
     * Background color of the explorer panel
     * @default '#2c313a'
     */
    backgroundColor?: string;
    /**
     * Whether the explorer should be open by default
     * @default false
     */
    initiallyOpen?: boolean;
    /**
     * Callback function that is called when a file is selected
     * @param filename The name/path of the selected file
     * @param view The current editor view
     */
    onFileSelect?: (filename: string, view: EditorView) => void;
}
/**
 * Creates a file explorer extension for CodeMirror
 */
export declare function explorer(options?: ExplorerOptions): Extension[];
export type { File };
export { updateFilesEffect, selectFileEffect, setProjectNameEffect, } from './state';
export { toggleExplorer } from './commands';
